16.91. cdist-type__mysql_privileges(7) — cdist 6.5.4 documentation

# 16.91. cdist-type__mysql_privileges(7)

## 16.91.1. NAME

cdist-type__mysql_privileges - Manage MySQL privileges

## 16.91.2. DESCRIPTION

Grant and revoke privileges of MySQL user.

## 16.91.3. REQUIRED PARAMETERS

database
  Name of database.
user
  Name of user.

## 16.91.4. OPTIONAL PARAMETERS

privileges
  Defaults to "all".
table
  Defaults to "*".
host
  Defaults to localhost.
state
  "present" grants and "absent" revokes. Defaults to present.

## 16.91.5. EXAMPLES

    __mysql_privileges user-to-db --database db --user user

## 16.91.6. AUTHORS

Ander Punnar <ander-at-kvlt-dot-ee>

## 16.91.7. COPYING

Copyright (C) 2020 Ander Punnar. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.